@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -58,7 +58,8 @@ void CompareExportFile::compareFiles()
                 mTempDir->setAutoRemove(false);
 #endif
             }
-            const auto *currentFile = static_cast<const KArchiveFile *>(currentEntry);
+            const auto currentFile =
+                static_cast<const KArchiveFile *>(currentEntry);
 
             QString adaptFile = file;
             //We store in zip as configs, but we extract in config/
