@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ class ExportNotesJobInterfaceTestImpl : public ExportNotesJobInterface, public E
     Q_OBJECT
 public:
     explicit ExportNotesJobInterfaceTestImpl(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ExportNotesJobInterfaceTestImpl();
+    ~ExportNotesJobInterfaceTestImpl() override;
 
 protected:
     void convertCollectionIdsToRealPath(KConfigGroup &selectFolderNoteGroup, const QString &selectFolderNoteGroupStr) override;
